#include <AFMotor.h>
#include <NewPing.h>

// Motor tanımları
AF_DCMotor motor1(1);
AF_DCMotor motor2(2);
AF_DCMotor motor3(3);
AF_DCMotor motor4(4);

// HC-SR04 tanımları
#define TRIG_PIN 37
#define ECHO_PIN 39
#define MAX_DISTANCE 200 // Maksimum algılama mesafesi (cm)
NewPing sonar(TRIG_PIN, ECHO_PIN, MAX_DISTANCE);

void setup() {
  Serial.begin(9600);
  Serial1.begin(9600);

  // Motorları başlat
  motor1.setSpeed(0);
  motor2.setSpeed(0);
  motor3.setSpeed(0);
  motor4.setSpeed(0);

  motor1.run(RELEASE);
  motor2.run(RELEASE);
  motor3.run(RELEASE);
  motor4.run(RELEASE);
}

void loop() {
  // Engel kontrolü
  if (checkObstacle()) {
    stopMotors();
    Serial.println("Engel algılandı! Robot durduruldu.");
    return;
  }

  if (Serial1.available()) {
    char command = Serial1.read(); // Veriyi char olarak oku
    if (command == '\n' || command == '\r' || command == ' ') {
      return; // Eğer komut geçersiz bir karakterse, fonksiyondan çık
    }
    Serial.print("Gelen komut: ");
    Serial.println(command);

    if (command == 'F') { // İleri git
      motor1.run(BACKWARD);
      motor2.run(FORWARD);
      motor3.run(BACKWARD);
      motor4.run(FORWARD);
      setSpeedAll(250);
    } else if (command == 'B') { // Geri git
      motor1.run(FORWARD);
      motor2.run(BACKWARD);
      motor3.run(FORWARD);
      motor4.run(BACKWARD);
      setSpeedAll(250);
    } else if (command == 'L') { // Sola git
      motor1.run(FORWARD);
      motor2.run(BACKWARD);
      motor3.run(BACKWARD);
      motor4.run(FORWARD);
      setSpeedAll(250);
    } else if (command == 'R') { // Sağa git
      motor1.run(BACKWARD);
      motor2.run(FORWARD);
      motor3.run(FORWARD);
      motor4.run(BACKWARD);
      setSpeedAll(250);
    } else if (command == 'Q') { // Sol çapraz (ileri sol)
      motor1.run(RELEASE); // Durdur
      motor2.run(RELEASE);
      motor3.run(BACKWARD);
      motor4.run(FORWARD);
      motor4.setSpeed(250);
      motor3.setSpeed(250);
    } else if (command == 'E') { // Sağ çapraz (ileri sağ)
      motor1.run(BACKWARD);
      motor2.run(FORWARD);
      motor3.run(RELEASE); // Durdur
      motor4.run(RELEASE);
      motor1.setSpeed(250);
      motor2.setSpeed(250);
    } else if (command == 'S') { // Motorları durdur
      stopMotors();
    } else {
      Serial.println("Bilinmeyen komut!");
    }
  }
}

// Tüm motorları durdurur
void stopMotors() {
  motor1.run(RELEASE);
  motor2.run(RELEASE);
  motor3.run(RELEASE);
  motor4.run(RELEASE);
}

// Tüm motor hızlarını ayarlar
void setSpeedAll(int speed) {
  motor1.setSpeed(speed);
  motor2.setSpeed(speed);
  motor3.setSpeed(speed);
  motor4.setSpeed(speed);
}

// Engel algılama fonksiyonu
bool checkObstacle() {
  unsigned int distance = sonar.ping_cm(); // Mesafeyi ölç
  if (distance > 0 && distance <= 15) {
    return true; // Engel algılandı
  }
  return false; // Engel yok
}

